from django.core.urlresolvers import resolve

__author__ = 'ir4y'


def url_name(request):
    result = {'url_name': None}
    try:
        path = request.get_full_path().split('?')[0]
        result['url_name'] = resolve(path).url_name
    except:
        pass
    return result



from django.db import models


def create_model(name, fields=None, app_label='', module='', options=None):
    """
    Create specified model
    """
    class Meta:
        # Using type('Meta', ...) gives a dictproxy error during model creation
        pass

    if app_label:
        # app_label must be set using the Meta inner class
        setattr(Meta, 'app_label', app_label)

    # Update Meta with any options that were provided
    if options is not None:
        for key, value in options.iteritems():
            setattr(Meta, key, value)

    # Set up a dictionary to simulate declarations within a class
    attrs = {'__module__': module, 'Meta': Meta}

    # Add in any fields that were provided
    if fields:
        attrs.update(fields)

    # Create the class, which automatically triggers ModelBase processing
    model = type(name, (models.Model,), attrs)

    return model



from tastypie.authorization import DjangoAuthorization
from tastypie.exceptions import Unauthorized

__author__ = 'ir4y'


class AuthorizationWithObjectPermissions(DjangoAuthorization):
        def create_list(self, object_list, bundle):
            klass = self.base_checks(bundle.request, object_list.model)

            if klass is False:
                return []

            permission = '%s.add_%s' % (klass._meta.app_label,
                                        klass._meta.module_name)

            if not bundle.request.user.has_perm(permission, object_list):
                return []

            return object_list

        def create_detail(self, object_list, bundle):
            klass = self.base_checks(bundle.request, bundle.obj.__class__)

            if klass is False:
                raise Unauthorized(
                    "You are not allowed to access that resource.")

            permission = '%s.add_%s' % (klass._meta.app_label,
                                        klass._meta.module_name)

            if not bundle.request.user.has_perm(permission):
                raise Unauthorized(
                    "You are not allowed to access that resource.")

            return True

        def update_list(self, object_list, bundle):
            klass = self.base_checks(bundle.request, object_list.model)

            if klass is False:
                return []

            permission = '%s.change_%s' % (klass._meta.app_label,
                                           klass._meta.module_name)

            if not bundle.request.user.has_perm(permission, object_list):
                return []

            return object_list

        def update_detail(self, object_list, bundle):
            klass = self.base_checks(bundle.request, bundle.obj.__class__)

            if klass is False:
                raise Unauthorized(
                    "You are not allowed to access that resource.")

            permission = '%s.change_%s' % (klass._meta.app_label,
                                           klass._meta.module_name)

            if not bundle.request.user.has_perm(permission, bundle.obj):
                raise Unauthorized(
                    "You are not allowed to access that resource.")

            return True

        def delete_list(self, object_list, bundle):
            klass = self.base_checks(bundle.request, object_list.model)

            if klass is False:
                return []

            permission = '%s.delete_%s' % (klass._meta.app_label,
                                           klass._meta.module_name)

            if not bundle.request.user.has_perm(permission, object_list):
                return []

            return object_list

        def delete_detail(self, object_list, bundle):
            klass = self.base_checks(bundle.request, bundle.obj.__class__)

            if klass is False:
                raise Unauthorized(
                    "You are not allowed to access that resource.")

            permission = '%s.delete_%s' % (klass._meta.app_label,
                                           klass._meta.module_name)

            if not bundle.request.user.has_perm(permission, bundle.obj):
                raise Unauthorized(
                    "You are not allowed to access that resource.")

            return True



from funcy import walk_values, compose
from django.db.models.fields import SlugField
from django.db.models.signals import post_save
from django.dispatch import receiver
from pytils.translit import slugify

try:
    from south.modelsinspector import add_introspection_rules
    add_introspection_rules([], ["^miniature\.models\.fields\.AutoSlugField"])
except ImportError:
    pass


class AutoSlugField(SlugField):
    def __init__(self, *args, **kwargs):
        self.populate_from = kwargs.pop('populate_from', '')
        kwargs['blank'] = True
        kwargs['null'] = True
        super(AutoSlugField, self).__init__(*args, **kwargs)

    def contribute_to_class(self, cls, name):
        self.set_attributes_from_name(name)
        self.model = cls
        cls._meta.add_field(self)

        @receiver(post_save, sender=cls, weak=False)
        def setup_slug(sender, instance, **kwargs):
            data = walk_values(compose(slugify, unicode),
                               instance.__dict__)
            slug = self.populate_from.format(
                **data)[:self.max_length]
            if slug != getattr(instance, name):
                setattr(instance, name, slug)
                instance.save()



from django.conf import settings
from django.utils.importlib import import_module
from tastypie.api import Api

__author__ = 'ir4y'


def resouce_autodiscover(api_name="v1", api_module_name="api"):
    api = Api(api_name=api_name)
    for app in settings.INSTALLED_APPS:
        try:
            resorce_api = import_module('%s.%s' % (app, api_module_name))
            for resource_klass_name in resorce_api.__all__:
                resource_klass = getattr(resorce_api, resource_klass_name)
                api.register(resource_klass())
        except:
            continue
    return api



# -*- coding: utf-8 -*-
import pytils
from django.db import models
from django.contrib.contenttypes.models import ContentType
from django.contrib.contenttypes import generic
from django.utils.translation import ugettext as _
from miniature.models.fields import AutoSlugField
from miniature.models.utils import create_model

__author__ = 'ir4y'


class ActiveManager(models.Manager):
    def active(self):
        return super(ActiveManager, self).get_queryset()\
                                         .filter(is_active='True')


class ActiveMixin(models.Model):
    is_active = models.BooleanField(verbose_name=_(u'Активно'), default=False)
    objects = ActiveManager()

    class Meta:
        abstract = True


class CreateUpdateMixin(models.Model):
    create = models.DateTimeField(auto_now_add=True,
                                  verbose_name=_(u'Дата создания'))
    update = models.DateTimeField(auto_now=True,
                                  verbose_name=_(u'Дата изменения'))

    class Meta:
        abstract = True


class SEOTagsMixin(models.Model):
    keywords = models.TextField(verbose_name=_(u'Ключевые слова'),
                                blank=True, null=True)
    description = models.TextField(verbose_name=_(u'Описание'),
                                   blank=True, null=True)

    class Meta:
        abstract = True


class GenericRelationMixin(models.Model):
    content_type = models.ForeignKey(ContentType)
    object_id = models.PositiveIntegerField()
    content_object = generic.GenericForeignKey('content_type', 'object_id')

    class Meta:
        abstract = True


def SlugTraits(base_filed_name='name'):
    """
    Функция генерирующая Mixin к модели
    Добавлющий _slug поле к указанному полю
    При сохраении в это поле записывается slug от указанного поля
    Описание класса на метаязыке
    class SlugMixin(models.Model):
        base_filed_name + '_slug' = models.CharField(
            verbose_name=_(u'Название для url'),max_length=150,
            blank=True,null=True)
        class Meta:
            abstract = True
    """
    fileld_name = base_filed_name + '_slug'
    fields = {
        fileld_name: AutoSlugField(verbose_name=_(u'Название для url'),
                                   populate_from='{' + base_filed_name + '}',
                                   max_length=150, blank=True, null=True)
    }
    _SlugMixin = create_model('SlugMixin', fields=fields,
                              module='miniature.models.mixins',
                              options={'abstract': True})
    return _SlugMixin



# -*- coding: utf-8 -*-
from django.utils.translation import ugettext as _

__author__ = 'ir4y'


def make_active(modeladmin, request, queryset):
    queryset.update(is_active=False)

make_active.short_description = _(u"Активировать")


def SlugAdminTraits(field_name='name'):
    slug_field_name = field_name + "_slug"

    class _SlugAdminMixin(object):
        def __init__(self, *args, **kwargs):
            if not self.readonly_fields:
                self.readonly_fields = []
            self.readonly_fields.extend([slug_field_name])
            super(_SlugAdminMixin, self).__init__(*args, **kwargs)
    return _SlugAdminMixin



from django.http import HttpResponse
from tastypie import resources

__author__ = 'ir4y'


def build_content_type(format, encoding='utf-8'):
    """
    Appends character encoding to the provided format if not already present.
    """
    if 'charset' in format:
        return format

    return "%s; charset=%s" % (format, encoding)


def create_response(self, request, data, response_class=HttpResponse,
                    **response_kwargs):
    desired_format = self.determine_format(request)
    serialized = self.serialize(request, data, desired_format)
    return response_class(content=serialized,
                          content_type=build_content_type(desired_format),
                          **response_kwargs)

setattr(resources.Resource, 'create_response', create_response)



import os
from setuptools import setup
from miniature import VERSION

f = open(os.path.join(os.path.dirname(__file__), 'README.md'))
readme = f.read()
f.close()

setup(
    name='miniature-ironman',
    version=".".join(map(str, VERSION)),
    description='My code snippets set for django',
    long_description=readme,
    author="Ilya Beda",
    author_email='ir4y.ix@gmail.com',
    url='https://github.com/ir4y/miniature-ironman',
    packages=['miniature'],
    include_package_data=True,
    install_requires=['setuptools', 'pytils', 'funcy'],
    zip_safe=False,
    classifiers=[
    'Development Status :: 4 - Beta',
        'Environment :: Web Environment',
        'Framework :: Django',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: BSD License',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
    ],
)



from django.template import Library

register = Library()


@register.filter
def get_range(value):
    """
      Filter - returns a list containing range made from given value
      Usage (in template):

      <ul>{% for i in 3|get_range %}
        <li>{{ i }}. Do something</li>
      {% endfor %}</ul>

      Results with the HTML:
      <ul>
        <li>0. Do something</li>
        <li>1. Do something</li>
        <li>2. Do something</li>
      </ul>

      Instead of 3 one may use the variable set in the views
    """
    return range(value)